export declare type ActionTypeMovement = "movement";
export declare type ActionTypeIdle = "idle";
export declare type ActionType = ActionTypeMovement | ActionTypeIdle;
export declare type Size = {
    width: number;
    height: number;
};
export declare type Duration = number | {
    min: number;
    max: number;
};
declare type NextAllowedAction = {
    name: string;
    possibility: number;
};
declare type AnimationBase = {
    frames: number;
    size: Size;
    duration: number;
};
declare type AnimationIdle = AnimationBase & {
    sprite: string;
};
declare type AnimationMove = AnimationBase & {
    spriteRight: string;
    spriteLeft: string;
    pxPerSecond: number;
};
export declare type Animation = AnimationIdle | AnimationMove;
declare type ActionBase<T extends ActionType> = {
    name: string;
    type: T;
    nextActions: NextAllowedAction[];
};
export declare type ActionMove = ActionBase<ActionTypeMovement> & {
    animation: AnimationMove;
};
export declare type ActionIdle = ActionBase<ActionTypeIdle> & {
    duration: Duration;
    animation: AnimationIdle;
};
export declare type Action = ActionMove | ActionIdle;
export declare type MovementMeta = {
    offsetX: number;
    duration: number;
    direction: number;
};
export declare type AnimalOptions = {
    actions: Action[];
    size: Size;
    element: HTMLElement;
};
export declare class Animal {
    id: string;
    private size;
    private positionOffset;
    actions: Action[];
    private currentAction;
    private timeoutId;
    private element;
    private styleElement;
    constructor(params: AnimalOptions);
    private getNextBoringRoutineByNext;
    private getNextBoringRoutine;
    startLiving(): void;
    private calculateDuration;
    private switchBoringRoutine;
    private getRandomPosition;
    private getOffsetPosition;
    private setLimbMovement;
    murderBrutally(): void;
}
export {};
